==> haskell-vector-instances-3.4.3-46-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-instances
version:              3.4.3
visibility:           public
id:                   vector-instances-3.4.3-C0uSgtYOdPMDMMcqe0pxUg
key:                  vector-instances-3.4.3-C0uSgtYOdPMDMMcqe0pxUg
license:              BSD-3-Clause
maintainer:           ekmett@gmail.com
author:               Edward Kmett
homepage:             http://github.com/ekmett/vector-instances
synopsis:             Orphan Instances for '\''Data.Vector'\''
description:          Orphan Instances for '\''Data.Vector'\''.
category:             Data, Data Structures
abi:                  7736d6dde73c31012e571c030c4e1e52
exposed:              True
exposed-modules:      Data.Vector.Instances
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-instances
hs-libraries:         HSvector-instances-3.4.3-C0uSgtYOdPMDMMcqe0pxUg
depends:
    base-4.17.2.1 comonad-5.0.9-7Nx7TLF48pI5LjqSes8omR
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    keys-3.12.4-jgAOCsevkzLQNJPvOYBGt
    pointed-5.0.5-6LsF8FOor3T8Aaa3MKOoZH
    semigroupoids-6.0.1-6I5b3GpOwhwAglmgd4w9RR
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57

haddock-interfaces:
    /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-instances-3.4.3-67-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-instances
version:              3.4.3
visibility:           public
id:                   vector-instances-3.4.3-HNE41dQsCL5JeIKsGsqeHY
key:                  vector-instances-3.4.3-HNE41dQsCL5JeIKsGsqeHY
license:              BSD-3-Clause
maintainer:           ekmett@gmail.com
author:               Edward Kmett
homepage:             http://github.com/ekmett/vector-instances
synopsis:             Orphan Instances for '\''Data.Vector'\''
description:          Orphan Instances for '\''Data.Vector'\''.
category:             Data, Data Structures
abi:                  5c3b0050fa623617652aa1b5d24f110c
exposed:              True
exposed-modules:      Data.Vector.Instances
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-instances
hs-libraries:         HSvector-instances-3.4.3-HNE41dQsCL5JeIKsGsqeHY
depends:
    base-4.17.2.1 comonad-5.0.9-69ztrEylAHVD4BHHoJEwKX
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    keys-3.12.4-DpfCnMB12A0EYS8FsAuzqm
    pointed-5.0.5-6eC2pML75v5INkJowEKF2w
    semigroupoids-6.0.1-Bxz0f1JNfGSLvZg0Ig0I9J
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:
    /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
